//  
//  Author:
//       smdn <smdn@smdn.jp>
// 
//  Copyright (c) 2003-2013 smdn
// 
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
// 
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
//  GNU General Public License for more details.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

using System;
using System.Text.RegularExpressions;

using Smdn.IO.FileSystems;

namespace Smdn.Applications.DirectoryAnalyzer.Analysis {
  public class AnalysisContext : TaskContext, ITaskContext
  {
    public AnalysisContext(Directory analysisDirectory)
    {
      this.parameter = new AnalysisParameter(analysisDirectory);
      this.status = new AnalysisStatus();
      this.result = new AnalysisResult();
    }

#region parameters
    private AnalysisParameter parameter = null;

    public AnalysisParameter Parameter
    {
      get
      {
        return this.parameter;
      }
    }
    
    public class AnalysisParameter : TaskParameter
    {
      private Directory analysisDirectory = null;

      public Directory AnalysisDirectory
      {
        get
        {
          return this.analysisDirectory;
        }
      }

      public string OutputFile = string.Empty;
      public int AnalysisDepth = 0;
#if false
      public bool PreAnalyze = true;
#endif
      public Predicate<DirectoryEntry> ScanPredicate = null;

      public AnalysisParameter(Directory analysisDirectory)
      {
        this.analysisDirectory = analysisDirectory;
      }
    }
#endregion

#region status
    private AnalysisStatus status = null;

    public AnalysisStatus Status
    {
      get
      {
        return this.status;
      }
    }

    public class AnalysisStatus : TaskStatus
    {
      public uint AnalyzedEntryCount = 0;

      public override uint Total
      {
        get
        {
          return 0U/*EntryCount.TotalEntryCount*/;
        }
      }

      public override uint Processed
      {
        get
        {
          return this.AnalyzedEntryCount;
        }
      }
    }
#endregion

#region results
    private AnalysisResult result = null;

    public AnalysisResult Result
    {
      get
      {
        return this.result;
      }
    }

    public class AnalysisResult : TaskResult
    {
      public DirectoryTree DirectoryTree = null;
    }
#endregion

    #region ITaskContext

    TaskContext.TaskParameter ITaskContext.Parameter
    {
      get { return this.parameter; }
    }

    TaskContext.TaskResult ITaskContext.Result
    {
      get { return this.result; }
    }

    TaskContext.TaskStatus ITaskContext.Status
    {
      get { return this.status; }
    }

    #endregion
  }
}
