//  
//  Author:
//       smdn <smdn@smdn.jp>
// 
//  Copyright (c) 2003-2013 smdn
// 
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
// 
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
//  GNU General Public License for more details.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

using System;
using System.Collections.Generic;
using System.IO;

namespace Smdn.Applications.DirectoryAnalyzer.Formatting {
  using Analysis;
  using Graphing;

  public class FormattingContext : TaskContext, ITaskContext
  {
    public FormattingContext()
    {
      this.parameter = new FormattingParameter();
      this.status = new FormattingStatus();
      this.result = new FormattingResult();
    }

    #region parameters
    private FormattingParameter parameter = null;

    public FormattingParameter Parameter
    {
      get
      {
        return this.parameter;
      }
    }

    public class FormattingParameter : TaskParameter
    {
      public FormatType Type = FormatType.Xml;
      public Graph Graph = null;
      // TODO: IReadOnlyCollection
      public ICollection<IGraphElement> FormattingElements = null;
      public TextWriter Writer = null;
      public Comparison<IGraphElement> Comparison = null;
    }
    #endregion

    #region status
    private FormattingStatus status = null;

    public FormattingStatus Status
    {
      get
      {
        return this.status;
      }
    }

    public class FormattingStatus : TaskStatus
    {
      public uint TotalEntryCount = 0;
      public uint FormattedEntryCount = 0;

      public override uint Total
      {
        get
        {
          return this.TotalEntryCount;
        }
      }

      public override uint Processed
      {
        get
        {
          return this.FormattedEntryCount;
        }
      }
    }
    #endregion

    #region results
    private FormattingResult result = null;

    public FormattingResult Result
    {
      get
      {
        return this.result;
      }
    }

    public class FormattingResult : TaskResult
    {
      public TextWriter Formatted = null;
    }
    #endregion

    #region ITaskContext

    TaskContext.TaskParameter ITaskContext.Parameter
    {
      get { return this.parameter; }
    }

    TaskContext.TaskResult ITaskContext.Result
    {
      get { return this.result; }
    }

    TaskContext.TaskStatus ITaskContext.Status
    {
      get { return this.status; }
    }

    #endregion
  }
}
